package com.ym.mec.biz.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ym.mec.auth.api.client.SysUserFeignService;
import com.ym.mec.auth.api.entity.SysUser;
import com.ym.mec.biz.dal.dao.CloudRoomFlowConfigDao;
import com.ym.mec.biz.dal.dto.CloudRoomFlowDto;
import com.ym.mec.biz.dal.entity.CloudRoomFlowConfig;
import com.ym.mec.biz.dal.entity.PlatformProduct;
import com.ym.mec.biz.service.CloudRoomFlowConfigService;
import com.ym.mec.common.exception.BizException;
import com.ym.mec.common.page.PageInfo;
import com.ym.mec.common.page.PageUtil;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Optional;

/**
 * @author hgw
 * Created by 2021-12-02
 */
@Service
public class CloudRoomFlowConfigServiceImpl extends ServiceImpl<CloudRoomFlowConfigDao, CloudRoomFlowConfig>
        implements CloudRoomFlowConfigService {

    @Autowired
    private SysUserFeignService sysUserFeignService;

    /**
     * 增加
     */
    @Override
    public void addConfig(CloudRoomFlowDto obj) {
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);
        CloudRoomFlowConfig config = new CloudRoomFlowConfig();
        config.setMinuteUpLimit(obj.getMinuteUpLimit());
        config.setPrice(obj.getPrice());
        config.setRemark(obj.getRemark());
        config.setDeleted(0);
        config.setCreatedBy(userId);
        config.setCreatedTime(new Date());
        baseMapper.insert(config);
    }

    /**
     * 修改
     */
    @Override
    public void updateConfig(CloudRoomFlowDto obj) {
        Optional.ofNullable(obj.getId()).orElseThrow(()->new BizException("id不能为空！"));
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);
        CloudRoomFlowConfig config = new CloudRoomFlowConfig();
        config.setId(obj.getId());
        config.setMinuteUpLimit(obj.getMinuteUpLimit());
        config.setPrice(obj.getPrice());
        config.setRemark(obj.getRemark());
        config.setUpdatedBy(userId);
        config.setUpdatedTime(new Date());
        baseMapper.updateByPrimaryKeySelective(config);
    }

    /**
     * 删除
     * @param id
     */
    @Override
    public void deleteConfig(Integer id){
        Optional.ofNullable(id).orElseThrow(()-> new BizException("Id不能为空"));
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);
        CloudRoomFlowConfig config = new CloudRoomFlowConfig();
        config.setId(id);
        config.setDeleted(1);
        config.setUpdatedBy(userId);
        config.setUpdatedTime(new Date());
        baseMapper.updateByPrimaryKeySelective(config);
    }

    /**
     * 分页查询
     *
     * @param minuteUp 分钟上限
     * @param page   页数
     * @param rows   查询数
     */
    @Override
    public PageInfo<CloudRoomFlowConfig> queryPage(Integer minuteUp, Integer page, Integer rows) {
        Page<CloudRoomFlowConfig> pageInfo = PageUtil.getPage(page, rows);
        pageInfo.setAsc("id_");
        IPage<CloudRoomFlowConfig> productIPage = baseMapper.queryPage(pageInfo, minuteUp);
        return PageUtil.pageInfo(productIPage);
    }

    /**
     * 查询分钟上限分组
     */
    public List<Integer> getGroupMinuteUp() {
        return baseMapper.getGroupMinuteUp();
    }

}
