package com.ym.mec.biz.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ym.mec.auth.api.client.SysUserFeignService;
import com.ym.mec.auth.api.entity.SysUser;
import com.ym.mec.biz.dal.dao.PlatformProductDao;
import com.ym.mec.biz.dal.dto.PlatformProductDto;
import com.ym.mec.biz.dal.entity.PlatformProduct;
import com.ym.mec.biz.service.PlatformProductService;
import com.ym.mec.common.exception.BizException;
import com.ym.mec.common.page.PageInfo;
import com.ym.mec.common.page.PageUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.Optional;

/**
 * @author hgw
 * Created by 2021-12-02
 */
@Service
public class PlatformProductServiceImpl extends ServiceImpl<PlatformProductDao, PlatformProduct> implements PlatformProductService {
    @Autowired
    private SysUserFeignService sysUserFeignService;

    /**
     * 增加
     */
    @Override
    public void addProduct(PlatformProductDto obj) {
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);

        PlatformProduct platformProduct = new PlatformProduct();
        platformProduct.setName(obj.getName());
        platformProduct.setMenuId(obj.getMenuId());
        platformProduct.setRemark(obj.getRemark());
        platformProduct.setDeleted(0);
        platformProduct.setCreatedBy(userId);
        platformProduct.setCreatedTime(new Date());
        baseMapper.insert(platformProduct);
    }

    /**
     * 修改
     */
    @Override
    public void updateProduct(PlatformProductDto obj) {
        Optional.ofNullable(obj.getId()).orElseThrow(()-> new BizException("产品Id不能为空"));
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);
        PlatformProduct platformProduct = new PlatformProduct();
        platformProduct.setName(obj.getName());
        platformProduct.setMenuId(obj.getMenuId());
        platformProduct.setRemark(obj.getRemark());
        platformProduct.setUpdatedBy(userId);
        platformProduct.setUpdatedTime(new Date());
        baseMapper.updateByPrimaryKeySelective(platformProduct);
    }

    /**
     * 删除
     * @param id 产品id
     */
    @Override
    public void deleteProduct(Integer id) {
        Optional.ofNullable(id).orElseThrow(()-> new BizException("产品Id不能为空"));
        Integer userId = Optional.ofNullable(sysUserFeignService.queryUserInfo())
                .map(SysUser::getId)
                .orElse(null);
        PlatformProduct platformProduct = new PlatformProduct();
        platformProduct.setId(id);
        platformProduct.setDeleted(1);
        platformProduct.setUpdatedBy(userId);
        platformProduct.setUpdatedTime(new Date());
        baseMapper.updateByPrimaryKeySelective(platformProduct);
    }

    /**
     * 分页查询
     *
     * @param search 关键字
     * @param page   页数
     * @param rows   查询数
     */
    @Override
    public PageInfo<PlatformProduct> queryPage(String search, Integer page, Integer rows) {
        Page<PlatformProduct> pageInfo = PageUtil.getPage(page, rows);
        pageInfo.setAsc("id_");
        IPage<PlatformProduct> productIPage = baseMapper.queryPage(pageInfo, search);
        return PageUtil.pageInfo(productIPage);
    }


}
