package com.ym.mec.web.controller;

import com.ym.mec.biz.dal.dto.CloudRoomFlowDto;
import com.ym.mec.biz.service.CloudRoomFlowConfigService;
import com.ym.mec.common.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * @author hgw
 * Created by 2021-12-06
 */
@RequestMapping("/cloudRoomFlowConfig")
@Api(tags = "云教室流量管理")
@RestController
public class CloudRoomFlowConfigController extends BaseController {

    @Autowired
    private CloudRoomFlowConfigService flowConfigService;

    @ApiOperation("分页查询")
    @GetMapping(value = "/queryPage")
    @PreAuthorize("@pcs.hasPermissions('cloudRoomFlowConfig/queryPage')")
    public Object queryPage(Integer minuteUp, Integer page, Integer rows) {
        return succeed(flowConfigService.queryPage(minuteUp, page, rows));
    }

    @ApiOperation("修改云教室流量")
    @PostMapping(value = "/update")
    @PreAuthorize("@pcs.hasPermissions('cloudRoomFlowConfig/update')")
    public Object updateProduct(@Valid @RequestBody CloudRoomFlowDto dto) {
        flowConfigService.updateConfig(dto);
        return succeed();
    }

    @ApiOperation("添加云教室流量")
    @PostMapping(value = "/add")
    @PreAuthorize("@pcs.hasPermissions('cloudRoomFlowConfig/add')")
    public Object addProduct(@Valid @RequestBody CloudRoomFlowDto dto) {
        flowConfigService.addConfig(dto);
        return succeed();
    }

    @ApiOperation("删除云教室流量")
    @GetMapping(value = "/delete/{id}")
    @PreAuthorize("@pcs.hasPermissions('cloudRoomFlowConfig/delete')")
    public Object deleteProduct(@ApiParam(value = "平台产品ID", required = true) @PathVariable("id") Integer id) {
        flowConfigService.deleteConfig(id);
        return succeed();
    }

    @ApiOperation("获取云教师流量包各分钟上限设置")
    @GetMapping(value = "/getMinuteUp")
    @PreAuthorize("@pcs.hasPermissions('cloudRoomFlowConfig/getMinuteUp')")
    public Object getGroupMinuteUp() {
        return succeed(flowConfigService.getGroupMinuteUp());
    }

}
